api.currentuser.v1 package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1 package

## Subpackages

- api.currentuser.v1.permission package
  - Submodules
  - api.currentuser.v1.permission.permission module
  - Module contents

## Submodules

## api.currentuser.v1.authmethods module

Autogenerated API

`api.currentuser.v1.authmethods.` `get_current_user_methods`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List the current users valid authentication methods (PUBLIC)

  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 705, “limit”: 126, “responseCode”: 200, “count”: 794, “data”: [{“method”: “OTP”, “lastLoginTimestamp”: 1447540604, “lastLoginIP”: “Trip board another popular trip president.”, “initialized”: true, “settings”: {“additionalProperties”: {}}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “To day fight else television.”, “messageTemplate”: “Establish artist money result hand.”, “field”: “Away southern staff notice people kind pull.”, “parameter”: {}, “timestamp”: 299413401}], “currentPage”: 779, “size”: 658}

## api.currentuser.v1.functions module

Autogenerated API

`api.currentuser.v1.functions.` `get_functions`(onlyRoles: bool = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List the current user’s permission functions regardless of customer (PUBLIC)

  Return type: | `dict`
  Parameters: | onlyRoles (bool) – Only return functions marked as roles keywords (list) – Filter functions by keywords on name and description offset (int) – Skip a number of functions limit (int) – Maximum number of returned functions
  Raises: | AuthenticationFailedException – on 401 ForbiddenPermissionException – on 403
  Returns: | {“offset”: 967, “limit”: 493, “responseCode”: 200, “count”: 106, “data”: [{“id”: 643, “name”: “Anthony Hunter”, “description”: “Keep could realize report produce any.”, “securityLevel”: “ADMINISTRATIVE”, “flags”: [“ROLE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Available happy laugh cup mention wife floor trade.”, “messageTemplate”: “Protect likely activity professional nice coach strategy.”, “field”: “Exactly win discover in.”, “parameter”: {}, “timestamp”: 1254512628}], “currentPage”: 842, “size”: 289}

## api.currentuser.v1.picture module

Autogenerated API

`api.currentuser.v1.picture.` `get_profile_picture`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get current user’s profile picture (PUBLIC)

  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ProfilePictureNotFoundException – on 404
  Returns: | {}

`api.currentuser.v1.picture.` `update_profile_picture`(picture: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Set current user’s profile picture (PUBLIC)

  Return type: | `dict`
  Parameters: | picture (str) – Image data url
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 83, “limit”: 669, “responseCode”: 200, “count”: 735, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Decide research marriage long recently various up research.”, “messageTemplate”: “Fear everything unit within network without season.”, “field”: “Best order number conference hit network response sign.”, “parameter”: {}, “timestamp”: 1187734135}], “currentPage”: 898, “size”: 496}

## api.currentuser.v1.prefs module

Autogenerated API

`api.currentuser.v1.prefs.` `delete_properties`(key: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete multiple current user’s preferences (PUBLIC)

  Return type: | `dict`
  Parameters: | key (list) – Keys to delete
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 376, “limit”: 742, “responseCode”: 200, “count”: 354, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Heavy manager question speech yard never.”, “messageTemplate”: “Hit nothing forward Democrat their war.”, “field”: “Operation world its community become.”, “parameter”: {}, “timestamp”: 829775524}], “currentPage”: 989, “size”: 491}

`api.currentuser.v1.prefs.` `delete_property`(propertyKey: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete the specified current user’s preference (PUBLIC)

  Return type: | `dict`
  Parameters: | propertyKey (str) – Preference key to delete
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 885, “limit”: 769, “responseCode”: 200, “count”: 251, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Listen fly animal current give main.”, “messageTemplate”: “Dinner wrong notice stock step consumer.”, “field”: “Year claim make treatment memory grow reduce man.”, “parameter”: {}, “timestamp”: 882384866}], “currentPage”: 811, “size”: 213}

`api.currentuser.v1.prefs.` `get_property`(propertyKey: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch a specific current user’ preference value (PUBLIC) Returns a the specified preference value, or null if not set

  Return type: | `dict`

`api.currentuser.v1.prefs.` `list_properties`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List all current user’s preferences (PUBLIC) Returns a dictionary of key/value pairs, defining all the users preferences

  > raises AuthenticationFailedException:
  > | on 401
  > returns: | {“offset”: 791, “limit”: 494, “responseCode”: 200, “count”: 240, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Base sort memory them whose feeling.”, “messageTemplate”: “Represent back how manager nothing.”, “field”: “Character commercial suffer star something game.”, “parameter”: {}, “timestamp”: 1036251586}], “currentPage”: 788, “size”: 805}

`api.currentuser.v1.prefs.` `set_properties`(body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Set the specified current user’s preferences (PUBLIC)

  Return type: | `dict`
  Parameters: | body (`str`) – Map of preference values to update
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 755, “limit”: 841, “responseCode”: 200, “count”: 795, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Power establish prepare movie prevent.”, “messageTemplate”: “Your example believe.”, “field”: “Daughter run now.”, “parameter”: {}, “timestamp”: 1408470621}], “currentPage”: 494, “size”: 107}

## api.currentuser.v1.user module

Autogenerated API

`api.currentuser.v1.user.` `get_current_user`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get the object representation of the currently logged in user (PUBLIC)

  Raises: | AuthenticationFailedException – on 401
  Returns: | {“offset”: 458, “limit”: 866, “responseCode”: 200, “count”: 583, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “World name describe give.”, “messageTemplate”: “Protect event light hit why.”, “field”: “Back story mention modern.”, “parameter”: {}, “timestamp”: 513026976}], “currentPage”: 359, “size”: 280}

## Module contents